# WaveYT

WaveYT is a simple Python package for downloading YouTube videos using `yt-dlp`. Designed for developers and general users alike, WaveYT makes downloading videos straightforward and efficient.

## Features

- Downloads YouTube videos in the best available video and audio format.
- Saves the downloaded video with its title as the filename.
- Easy-to-use command-line interface (CLI).

## Installation

To install WaveYT, simply use pip:

```bash
pip install WaveYT
```

## How to Use

Here is an example of how to use WaveYT in Python:

```python
import yt_dlp

def download_youtube_video():
    # Get the YouTube link from the user
    video_url = input("Enter the YouTube video URL: ")

    # Define download options
    ydl_opts = {
        'format': 'best',  # Best video+audio format
        'outtmpl': '%(title)s.%(ext)s',  # Save file as the video's title
    }

    try:
        # Download the video
        with yt_dlp.YoutubeDL(ydl_opts) as ydl:
            info = ydl.extract_info(video_url, download=True)
            print(f"Downloaded: {info['title']}")
    except Exception as e:
        print("Error:", e)

if __name__ == "__main__":
    download_youtube_video()
```

You can now copy and paste this code to use WaveYT effortlessly!

